# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTDiscountParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'percent_off': 'int',
        'amount_off': 'int',
        'coupon_type': 'int',
        'coupon_valid_months': 'int',
        'expires_in_days': 'int',
        'plan_id': 'str'
    }

    attribute_map = {
        'percent_off': 'percentOff',
        'amount_off': 'amountOff',
        'coupon_type': 'couponType',
        'coupon_valid_months': 'couponValidMonths',
        'expires_in_days': 'expiresInDays',
        'plan_id': 'planId'
    }

    def __init__(self, percent_off=None, amount_off=None, coupon_type=None, coupon_valid_months=None, expires_in_days=None, plan_id=None):  # noqa: E501
        """BTDiscountParams - a model defined in OpenAPI"""  # noqa: E501

        self._percent_off = None
        self._amount_off = None
        self._coupon_type = None
        self._coupon_valid_months = None
        self._expires_in_days = None
        self._plan_id = None
        self.discriminator = None

        if percent_off is not None:
            self.percent_off = percent_off
        if amount_off is not None:
            self.amount_off = amount_off
        if coupon_type is not None:
            self.coupon_type = coupon_type
        if coupon_valid_months is not None:
            self.coupon_valid_months = coupon_valid_months
        if expires_in_days is not None:
            self.expires_in_days = expires_in_days
        if plan_id is not None:
            self.plan_id = plan_id

    @property
    def percent_off(self):
        """Gets the percent_off of this BTDiscountParams.  # noqa: E501


        :return: The percent_off of this BTDiscountParams.  # noqa: E501
        :rtype: int
        """
        return self._percent_off

    @percent_off.setter
    def percent_off(self, percent_off):
        """Sets the percent_off of this BTDiscountParams.


        :param percent_off: The percent_off of this BTDiscountParams.  # noqa: E501
        :type: int
        """

        self._percent_off = percent_off

    @property
    def amount_off(self):
        """Gets the amount_off of this BTDiscountParams.  # noqa: E501


        :return: The amount_off of this BTDiscountParams.  # noqa: E501
        :rtype: int
        """
        return self._amount_off

    @amount_off.setter
    def amount_off(self, amount_off):
        """Sets the amount_off of this BTDiscountParams.


        :param amount_off: The amount_off of this BTDiscountParams.  # noqa: E501
        :type: int
        """

        self._amount_off = amount_off

    @property
    def coupon_type(self):
        """Gets the coupon_type of this BTDiscountParams.  # noqa: E501


        :return: The coupon_type of this BTDiscountParams.  # noqa: E501
        :rtype: int
        """
        return self._coupon_type

    @coupon_type.setter
    def coupon_type(self, coupon_type):
        """Sets the coupon_type of this BTDiscountParams.


        :param coupon_type: The coupon_type of this BTDiscountParams.  # noqa: E501
        :type: int
        """

        self._coupon_type = coupon_type

    @property
    def coupon_valid_months(self):
        """Gets the coupon_valid_months of this BTDiscountParams.  # noqa: E501


        :return: The coupon_valid_months of this BTDiscountParams.  # noqa: E501
        :rtype: int
        """
        return self._coupon_valid_months

    @coupon_valid_months.setter
    def coupon_valid_months(self, coupon_valid_months):
        """Sets the coupon_valid_months of this BTDiscountParams.


        :param coupon_valid_months: The coupon_valid_months of this BTDiscountParams.  # noqa: E501
        :type: int
        """

        self._coupon_valid_months = coupon_valid_months

    @property
    def expires_in_days(self):
        """Gets the expires_in_days of this BTDiscountParams.  # noqa: E501


        :return: The expires_in_days of this BTDiscountParams.  # noqa: E501
        :rtype: int
        """
        return self._expires_in_days

    @expires_in_days.setter
    def expires_in_days(self, expires_in_days):
        """Sets the expires_in_days of this BTDiscountParams.


        :param expires_in_days: The expires_in_days of this BTDiscountParams.  # noqa: E501
        :type: int
        """

        self._expires_in_days = expires_in_days

    @property
    def plan_id(self):
        """Gets the plan_id of this BTDiscountParams.  # noqa: E501


        :return: The plan_id of this BTDiscountParams.  # noqa: E501
        :rtype: str
        """
        return self._plan_id

    @plan_id.setter
    def plan_id(self, plan_id):
        """Sets the plan_id of this BTDiscountParams.


        :param plan_id: The plan_id of this BTDiscountParams.  # noqa: E501
        :type: str
        """

        self._plan_id = plan_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTDiscountParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTAppElementReferenceResolveInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'target_element_microversion_id': 'str',
        'resolved_element_microversion_id': 'str',
        'id_tag': 'str',
        'revision': 'str',
        'part_number': 'str',
        'change_id': 'str',
        'target_version_id': 'str',
        'is_sketch_only': 'bool',
        'target_configuration': 'str',
        'reference_id': 'str',
        'target_document_id': 'str',
        'target_element_id': 'str',
        'target_document_microversion_id': 'str',
        'is_configurable': 'bool',
        'resolved_document_microversion_id': 'str',
        'id_tag_is_valid': 'bool',
        'is_flattened_part': 'bool',
        'track_new_versions': 'bool',
        'sketch_ids': 'list[str]',
        'error_code': 'int',
        'error_value': 'str',
        'error_description': 'str'
    }

    attribute_map = {
        'target_element_microversion_id': 'targetElementMicroversionId',
        'resolved_element_microversion_id': 'resolvedElementMicroversionId',
        'id_tag': 'idTag',
        'revision': 'revision',
        'part_number': 'partNumber',
        'change_id': 'changeId',
        'target_version_id': 'targetVersionId',
        'is_sketch_only': 'isSketchOnly',
        'target_configuration': 'targetConfiguration',
        'reference_id': 'referenceId',
        'target_document_id': 'targetDocumentId',
        'target_element_id': 'targetElementId',
        'target_document_microversion_id': 'targetDocumentMicroversionId',
        'is_configurable': 'isConfigurable',
        'resolved_document_microversion_id': 'resolvedDocumentMicroversionId',
        'id_tag_is_valid': 'idTagIsValid',
        'is_flattened_part': 'isFlattenedPart',
        'track_new_versions': 'trackNewVersions',
        'sketch_ids': 'sketchIds',
        'error_code': 'errorCode',
        'error_value': 'errorValue',
        'error_description': 'errorDescription'
    }

    def __init__(self, target_element_microversion_id=None, resolved_element_microversion_id=None, id_tag=None, revision=None, part_number=None, change_id=None, target_version_id=None, is_sketch_only=None, target_configuration=None, reference_id=None, target_document_id=None, target_element_id=None, target_document_microversion_id=None, is_configurable=None, resolved_document_microversion_id=None, id_tag_is_valid=None, is_flattened_part=None, track_new_versions=None, sketch_ids=None, error_code=None, error_value=None, error_description=None):  # noqa: E501
        """BTAppElementReferenceResolveInfo - a model defined in OpenAPI"""  # noqa: E501

        self._target_element_microversion_id = None
        self._resolved_element_microversion_id = None
        self._id_tag = None
        self._revision = None
        self._part_number = None
        self._change_id = None
        self._target_version_id = None
        self._is_sketch_only = None
        self._target_configuration = None
        self._reference_id = None
        self._target_document_id = None
        self._target_element_id = None
        self._target_document_microversion_id = None
        self._is_configurable = None
        self._resolved_document_microversion_id = None
        self._id_tag_is_valid = None
        self._is_flattened_part = None
        self._track_new_versions = None
        self._sketch_ids = None
        self._error_code = None
        self._error_value = None
        self._error_description = None
        self.discriminator = None

        if target_element_microversion_id is not None:
            self.target_element_microversion_id = target_element_microversion_id
        if resolved_element_microversion_id is not None:
            self.resolved_element_microversion_id = resolved_element_microversion_id
        if id_tag is not None:
            self.id_tag = id_tag
        if revision is not None:
            self.revision = revision
        if part_number is not None:
            self.part_number = part_number
        if change_id is not None:
            self.change_id = change_id
        if target_version_id is not None:
            self.target_version_id = target_version_id
        if is_sketch_only is not None:
            self.is_sketch_only = is_sketch_only
        if target_configuration is not None:
            self.target_configuration = target_configuration
        if reference_id is not None:
            self.reference_id = reference_id
        if target_document_id is not None:
            self.target_document_id = target_document_id
        if target_element_id is not None:
            self.target_element_id = target_element_id
        if target_document_microversion_id is not None:
            self.target_document_microversion_id = target_document_microversion_id
        if is_configurable is not None:
            self.is_configurable = is_configurable
        if resolved_document_microversion_id is not None:
            self.resolved_document_microversion_id = resolved_document_microversion_id
        if id_tag_is_valid is not None:
            self.id_tag_is_valid = id_tag_is_valid
        if is_flattened_part is not None:
            self.is_flattened_part = is_flattened_part
        if track_new_versions is not None:
            self.track_new_versions = track_new_versions
        if sketch_ids is not None:
            self.sketch_ids = sketch_ids
        if error_code is not None:
            self.error_code = error_code
        if error_value is not None:
            self.error_value = error_value
        if error_description is not None:
            self.error_description = error_description

    @property
    def target_element_microversion_id(self):
        """Gets the target_element_microversion_id of this BTAppElementReferenceResolveInfo.  # noqa: E501


        :return: The target_element_microversion_id of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :rtype: str
        """
        return self._target_element_microversion_id

    @target_element_microversion_id.setter
    def target_element_microversion_id(self, target_element_microversion_id):
        """Sets the target_element_microversion_id of this BTAppElementReferenceResolveInfo.


        :param target_element_microversion_id: The target_element_microversion_id of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :type: str
        """

        self._target_element_microversion_id = target_element_microversion_id

    @property
    def resolved_element_microversion_id(self):
        """Gets the resolved_element_microversion_id of this BTAppElementReferenceResolveInfo.  # noqa: E501


        :return: The resolved_element_microversion_id of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :rtype: str
        """
        return self._resolved_element_microversion_id

    @resolved_element_microversion_id.setter
    def resolved_element_microversion_id(self, resolved_element_microversion_id):
        """Sets the resolved_element_microversion_id of this BTAppElementReferenceResolveInfo.


        :param resolved_element_microversion_id: The resolved_element_microversion_id of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :type: str
        """

        self._resolved_element_microversion_id = resolved_element_microversion_id

    @property
    def id_tag(self):
        """Gets the id_tag of this BTAppElementReferenceResolveInfo.  # noqa: E501


        :return: The id_tag of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :rtype: str
        """
        return self._id_tag

    @id_tag.setter
    def id_tag(self, id_tag):
        """Sets the id_tag of this BTAppElementReferenceResolveInfo.


        :param id_tag: The id_tag of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :type: str
        """

        self._id_tag = id_tag

    @property
    def revision(self):
        """Gets the revision of this BTAppElementReferenceResolveInfo.  # noqa: E501


        :return: The revision of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :rtype: str
        """
        return self._revision

    @revision.setter
    def revision(self, revision):
        """Sets the revision of this BTAppElementReferenceResolveInfo.


        :param revision: The revision of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :type: str
        """

        self._revision = revision

    @property
    def part_number(self):
        """Gets the part_number of this BTAppElementReferenceResolveInfo.  # noqa: E501


        :return: The part_number of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :rtype: str
        """
        return self._part_number

    @part_number.setter
    def part_number(self, part_number):
        """Sets the part_number of this BTAppElementReferenceResolveInfo.


        :param part_number: The part_number of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :type: str
        """

        self._part_number = part_number

    @property
    def change_id(self):
        """Gets the change_id of this BTAppElementReferenceResolveInfo.  # noqa: E501


        :return: The change_id of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :rtype: str
        """
        return self._change_id

    @change_id.setter
    def change_id(self, change_id):
        """Sets the change_id of this BTAppElementReferenceResolveInfo.


        :param change_id: The change_id of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :type: str
        """

        self._change_id = change_id

    @property
    def target_version_id(self):
        """Gets the target_version_id of this BTAppElementReferenceResolveInfo.  # noqa: E501


        :return: The target_version_id of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :rtype: str
        """
        return self._target_version_id

    @target_version_id.setter
    def target_version_id(self, target_version_id):
        """Sets the target_version_id of this BTAppElementReferenceResolveInfo.


        :param target_version_id: The target_version_id of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :type: str
        """

        self._target_version_id = target_version_id

    @property
    def is_sketch_only(self):
        """Gets the is_sketch_only of this BTAppElementReferenceResolveInfo.  # noqa: E501


        :return: The is_sketch_only of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_sketch_only

    @is_sketch_only.setter
    def is_sketch_only(self, is_sketch_only):
        """Sets the is_sketch_only of this BTAppElementReferenceResolveInfo.


        :param is_sketch_only: The is_sketch_only of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :type: bool
        """

        self._is_sketch_only = is_sketch_only

    @property
    def target_configuration(self):
        """Gets the target_configuration of this BTAppElementReferenceResolveInfo.  # noqa: E501


        :return: The target_configuration of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :rtype: str
        """
        return self._target_configuration

    @target_configuration.setter
    def target_configuration(self, target_configuration):
        """Sets the target_configuration of this BTAppElementReferenceResolveInfo.


        :param target_configuration: The target_configuration of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :type: str
        """

        self._target_configuration = target_configuration

    @property
    def reference_id(self):
        """Gets the reference_id of this BTAppElementReferenceResolveInfo.  # noqa: E501


        :return: The reference_id of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :rtype: str
        """
        return self._reference_id

    @reference_id.setter
    def reference_id(self, reference_id):
        """Sets the reference_id of this BTAppElementReferenceResolveInfo.


        :param reference_id: The reference_id of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :type: str
        """

        self._reference_id = reference_id

    @property
    def target_document_id(self):
        """Gets the target_document_id of this BTAppElementReferenceResolveInfo.  # noqa: E501


        :return: The target_document_id of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :rtype: str
        """
        return self._target_document_id

    @target_document_id.setter
    def target_document_id(self, target_document_id):
        """Sets the target_document_id of this BTAppElementReferenceResolveInfo.


        :param target_document_id: The target_document_id of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :type: str
        """

        self._target_document_id = target_document_id

    @property
    def target_element_id(self):
        """Gets the target_element_id of this BTAppElementReferenceResolveInfo.  # noqa: E501


        :return: The target_element_id of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :rtype: str
        """
        return self._target_element_id

    @target_element_id.setter
    def target_element_id(self, target_element_id):
        """Sets the target_element_id of this BTAppElementReferenceResolveInfo.


        :param target_element_id: The target_element_id of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :type: str
        """

        self._target_element_id = target_element_id

    @property
    def target_document_microversion_id(self):
        """Gets the target_document_microversion_id of this BTAppElementReferenceResolveInfo.  # noqa: E501


        :return: The target_document_microversion_id of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :rtype: str
        """
        return self._target_document_microversion_id

    @target_document_microversion_id.setter
    def target_document_microversion_id(self, target_document_microversion_id):
        """Sets the target_document_microversion_id of this BTAppElementReferenceResolveInfo.


        :param target_document_microversion_id: The target_document_microversion_id of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :type: str
        """

        self._target_document_microversion_id = target_document_microversion_id

    @property
    def is_configurable(self):
        """Gets the is_configurable of this BTAppElementReferenceResolveInfo.  # noqa: E501


        :return: The is_configurable of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_configurable

    @is_configurable.setter
    def is_configurable(self, is_configurable):
        """Sets the is_configurable of this BTAppElementReferenceResolveInfo.


        :param is_configurable: The is_configurable of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :type: bool
        """

        self._is_configurable = is_configurable

    @property
    def resolved_document_microversion_id(self):
        """Gets the resolved_document_microversion_id of this BTAppElementReferenceResolveInfo.  # noqa: E501


        :return: The resolved_document_microversion_id of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :rtype: str
        """
        return self._resolved_document_microversion_id

    @resolved_document_microversion_id.setter
    def resolved_document_microversion_id(self, resolved_document_microversion_id):
        """Sets the resolved_document_microversion_id of this BTAppElementReferenceResolveInfo.


        :param resolved_document_microversion_id: The resolved_document_microversion_id of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :type: str
        """

        self._resolved_document_microversion_id = resolved_document_microversion_id

    @property
    def id_tag_is_valid(self):
        """Gets the id_tag_is_valid of this BTAppElementReferenceResolveInfo.  # noqa: E501


        :return: The id_tag_is_valid of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :rtype: bool
        """
        return self._id_tag_is_valid

    @id_tag_is_valid.setter
    def id_tag_is_valid(self, id_tag_is_valid):
        """Sets the id_tag_is_valid of this BTAppElementReferenceResolveInfo.


        :param id_tag_is_valid: The id_tag_is_valid of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :type: bool
        """

        self._id_tag_is_valid = id_tag_is_valid

    @property
    def is_flattened_part(self):
        """Gets the is_flattened_part of this BTAppElementReferenceResolveInfo.  # noqa: E501


        :return: The is_flattened_part of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_flattened_part

    @is_flattened_part.setter
    def is_flattened_part(self, is_flattened_part):
        """Sets the is_flattened_part of this BTAppElementReferenceResolveInfo.


        :param is_flattened_part: The is_flattened_part of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :type: bool
        """

        self._is_flattened_part = is_flattened_part

    @property
    def track_new_versions(self):
        """Gets the track_new_versions of this BTAppElementReferenceResolveInfo.  # noqa: E501


        :return: The track_new_versions of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :rtype: bool
        """
        return self._track_new_versions

    @track_new_versions.setter
    def track_new_versions(self, track_new_versions):
        """Sets the track_new_versions of this BTAppElementReferenceResolveInfo.


        :param track_new_versions: The track_new_versions of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :type: bool
        """

        self._track_new_versions = track_new_versions

    @property
    def sketch_ids(self):
        """Gets the sketch_ids of this BTAppElementReferenceResolveInfo.  # noqa: E501


        :return: The sketch_ids of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._sketch_ids

    @sketch_ids.setter
    def sketch_ids(self, sketch_ids):
        """Sets the sketch_ids of this BTAppElementReferenceResolveInfo.


        :param sketch_ids: The sketch_ids of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :type: list[str]
        """

        self._sketch_ids = sketch_ids

    @property
    def error_code(self):
        """Gets the error_code of this BTAppElementReferenceResolveInfo.  # noqa: E501


        :return: The error_code of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :rtype: int
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """Sets the error_code of this BTAppElementReferenceResolveInfo.


        :param error_code: The error_code of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :type: int
        """

        self._error_code = error_code

    @property
    def error_value(self):
        """Gets the error_value of this BTAppElementReferenceResolveInfo.  # noqa: E501


        :return: The error_value of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :rtype: str
        """
        return self._error_value

    @error_value.setter
    def error_value(self, error_value):
        """Sets the error_value of this BTAppElementReferenceResolveInfo.


        :param error_value: The error_value of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :type: str
        """
        allowed_values = ["OK", "TRANSACTION_CONFLICT", "NOT_FOUND", "INCONSISTENT_CHANGES"]  # noqa: E501
        if error_value not in allowed_values:
            raise ValueError(
                "Invalid value for `error_value` ({0}), must be one of {1}"  # noqa: E501
                .format(error_value, allowed_values)
            )

        self._error_value = error_value

    @property
    def error_description(self):
        """Gets the error_description of this BTAppElementReferenceResolveInfo.  # noqa: E501


        :return: The error_description of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :rtype: str
        """
        return self._error_description

    @error_description.setter
    def error_description(self, error_description):
        """Sets the error_description of this BTAppElementReferenceResolveInfo.


        :param error_description: The error_description of this BTAppElementReferenceResolveInfo.  # noqa: E501
        :type: str
        """

        self._error_description = error_description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTAppElementReferenceResolveInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTInsertionLocation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'order_preserving': 'bool',
        'adjacent_to_node': 'bool',
        'node_id': 'str',
        'node_id_raw': 'BTObjectId',
        'child_field_index': 'int',
        'before': 'bool',
        'type_id': 'int',
        'connection_source': 'BTConnection',
        'export_type_name': 'str',
        'unknown_class': 'bool'
    }

    attribute_map = {
        'order_preserving': 'orderPreserving',
        'adjacent_to_node': 'adjacentToNode',
        'node_id': 'nodeId',
        'node_id_raw': 'nodeIdRaw',
        'child_field_index': 'childFieldIndex',
        'before': 'before',
        'type_id': 'typeId',
        'connection_source': 'connectionSource',
        'export_type_name': 'exportTypeName',
        'unknown_class': 'unknownClass'
    }

    def __init__(self, order_preserving=None, adjacent_to_node=None, node_id=None, node_id_raw=None, child_field_index=None, before=None, type_id=None, connection_source=None, export_type_name=None, unknown_class=None):  # noqa: E501
        """BTInsertionLocation - a model defined in OpenAPI"""  # noqa: E501

        self._order_preserving = None
        self._adjacent_to_node = None
        self._node_id = None
        self._node_id_raw = None
        self._child_field_index = None
        self._before = None
        self._type_id = None
        self._connection_source = None
        self._export_type_name = None
        self._unknown_class = None
        self.discriminator = None

        if order_preserving is not None:
            self.order_preserving = order_preserving
        if adjacent_to_node is not None:
            self.adjacent_to_node = adjacent_to_node
        if node_id is not None:
            self.node_id = node_id
        if node_id_raw is not None:
            self.node_id_raw = node_id_raw
        if child_field_index is not None:
            self.child_field_index = child_field_index
        if before is not None:
            self.before = before
        if type_id is not None:
            self.type_id = type_id
        if connection_source is not None:
            self.connection_source = connection_source
        if export_type_name is not None:
            self.export_type_name = export_type_name
        if unknown_class is not None:
            self.unknown_class = unknown_class

    @property
    def order_preserving(self):
        """Gets the order_preserving of this BTInsertionLocation.  # noqa: E501


        :return: The order_preserving of this BTInsertionLocation.  # noqa: E501
        :rtype: bool
        """
        return self._order_preserving

    @order_preserving.setter
    def order_preserving(self, order_preserving):
        """Sets the order_preserving of this BTInsertionLocation.


        :param order_preserving: The order_preserving of this BTInsertionLocation.  # noqa: E501
        :type: bool
        """

        self._order_preserving = order_preserving

    @property
    def adjacent_to_node(self):
        """Gets the adjacent_to_node of this BTInsertionLocation.  # noqa: E501


        :return: The adjacent_to_node of this BTInsertionLocation.  # noqa: E501
        :rtype: bool
        """
        return self._adjacent_to_node

    @adjacent_to_node.setter
    def adjacent_to_node(self, adjacent_to_node):
        """Sets the adjacent_to_node of this BTInsertionLocation.


        :param adjacent_to_node: The adjacent_to_node of this BTInsertionLocation.  # noqa: E501
        :type: bool
        """

        self._adjacent_to_node = adjacent_to_node

    @property
    def node_id(self):
        """Gets the node_id of this BTInsertionLocation.  # noqa: E501


        :return: The node_id of this BTInsertionLocation.  # noqa: E501
        :rtype: str
        """
        return self._node_id

    @node_id.setter
    def node_id(self, node_id):
        """Sets the node_id of this BTInsertionLocation.


        :param node_id: The node_id of this BTInsertionLocation.  # noqa: E501
        :type: str
        """

        self._node_id = node_id

    @property
    def node_id_raw(self):
        """Gets the node_id_raw of this BTInsertionLocation.  # noqa: E501


        :return: The node_id_raw of this BTInsertionLocation.  # noqa: E501
        :rtype: BTObjectId
        """
        return self._node_id_raw

    @node_id_raw.setter
    def node_id_raw(self, node_id_raw):
        """Sets the node_id_raw of this BTInsertionLocation.


        :param node_id_raw: The node_id_raw of this BTInsertionLocation.  # noqa: E501
        :type: BTObjectId
        """

        self._node_id_raw = node_id_raw

    @property
    def child_field_index(self):
        """Gets the child_field_index of this BTInsertionLocation.  # noqa: E501


        :return: The child_field_index of this BTInsertionLocation.  # noqa: E501
        :rtype: int
        """
        return self._child_field_index

    @child_field_index.setter
    def child_field_index(self, child_field_index):
        """Sets the child_field_index of this BTInsertionLocation.


        :param child_field_index: The child_field_index of this BTInsertionLocation.  # noqa: E501
        :type: int
        """

        self._child_field_index = child_field_index

    @property
    def before(self):
        """Gets the before of this BTInsertionLocation.  # noqa: E501


        :return: The before of this BTInsertionLocation.  # noqa: E501
        :rtype: bool
        """
        return self._before

    @before.setter
    def before(self, before):
        """Sets the before of this BTInsertionLocation.


        :param before: The before of this BTInsertionLocation.  # noqa: E501
        :type: bool
        """

        self._before = before

    @property
    def type_id(self):
        """Gets the type_id of this BTInsertionLocation.  # noqa: E501


        :return: The type_id of this BTInsertionLocation.  # noqa: E501
        :rtype: int
        """
        return self._type_id

    @type_id.setter
    def type_id(self, type_id):
        """Sets the type_id of this BTInsertionLocation.


        :param type_id: The type_id of this BTInsertionLocation.  # noqa: E501
        :type: int
        """

        self._type_id = type_id

    @property
    def connection_source(self):
        """Gets the connection_source of this BTInsertionLocation.  # noqa: E501


        :return: The connection_source of this BTInsertionLocation.  # noqa: E501
        :rtype: BTConnection
        """
        return self._connection_source

    @connection_source.setter
    def connection_source(self, connection_source):
        """Sets the connection_source of this BTInsertionLocation.


        :param connection_source: The connection_source of this BTInsertionLocation.  # noqa: E501
        :type: BTConnection
        """

        self._connection_source = connection_source

    @property
    def export_type_name(self):
        """Gets the export_type_name of this BTInsertionLocation.  # noqa: E501


        :return: The export_type_name of this BTInsertionLocation.  # noqa: E501
        :rtype: str
        """
        return self._export_type_name

    @export_type_name.setter
    def export_type_name(self, export_type_name):
        """Sets the export_type_name of this BTInsertionLocation.


        :param export_type_name: The export_type_name of this BTInsertionLocation.  # noqa: E501
        :type: str
        """

        self._export_type_name = export_type_name

    @property
    def unknown_class(self):
        """Gets the unknown_class of this BTInsertionLocation.  # noqa: E501


        :return: The unknown_class of this BTInsertionLocation.  # noqa: E501
        :rtype: bool
        """
        return self._unknown_class

    @unknown_class.setter
    def unknown_class(self, unknown_class):
        """Sets the unknown_class of this BTInsertionLocation.


        :param unknown_class: The unknown_class of this BTInsertionLocation.  # noqa: E501
        :type: bool
        """

        self._unknown_class = unknown_class

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTInsertionLocation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from onshape_client.configuration import Configuration
import onshape_client
from pathlib import Path
from ruamel.yaml import YAML
from onshape_client.models.bt_configuration_params import BTConfigurationParams
import six
import json

class Client:

    def __init__(self, stack='prod'):

        # Get the YAML file that contains the configuration params
        yaml = YAML()
        path = '../.onshape_client_config.yaml'
        onshape_client_config = yaml.load(Path(path))

        # Load the API keys and URL into the configuration
        self.configuration = Configuration()
        conf = onshape_client_config[stack]
        self.configuration.api_key['SECRET_KEY'] = conf['api_keys']['secret_key'].encode('utf-8')
        self.configuration.api_key['ACCESS_KEY'] = conf['api_keys']['access_key'].encode('utf-8')
        self.configuration.host = conf['baseUrl']

        apiClient = api_client
        # Create the API instance with the configuration
        self.ElementsApi = onshape_client.api.ElementsApi(apiClient)
        self.MetadataApi = onshape_client.api.MetadataApi(apiClient)
        self.PartStudiosApi = onshape_client.api.PartStudiosApi(apiClient)



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTBetaCapabilityParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'id': 'str',
        'description': 'str',
        'capability': 'str',
        'eula': 'str',
        'approvals_per_hour': 'float',
        'auto_approve': 'bool',
        'auto_approve_paid': 'bool',
        'auto_approve_onshape': 'bool',
        'upgradable': 'bool',
        'user_based': 'bool',
        'self_service_disabled': 'bool',
        'user_limit': 'int',
        'welcome_html': 'str'
    }

    attribute_map = {
        'name': 'name',
        'id': 'id',
        'description': 'description',
        'capability': 'capability',
        'eula': 'eula',
        'approvals_per_hour': 'approvalsPerHour',
        'auto_approve': 'autoApprove',
        'auto_approve_paid': 'autoApprovePaid',
        'auto_approve_onshape': 'autoApproveOnshape',
        'upgradable': 'upgradable',
        'user_based': 'userBased',
        'self_service_disabled': 'selfServiceDisabled',
        'user_limit': 'userLimit',
        'welcome_html': 'welcomeHTML'
    }

    def __init__(self, name=None, id=None, description=None, capability=None, eula=None, approvals_per_hour=None, auto_approve=None, auto_approve_paid=None, auto_approve_onshape=None, upgradable=None, user_based=None, self_service_disabled=None, user_limit=None, welcome_html=None):  # noqa: E501
        """BTBetaCapabilityParams - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self._id = None
        self._description = None
        self._capability = None
        self._eula = None
        self._approvals_per_hour = None
        self._auto_approve = None
        self._auto_approve_paid = None
        self._auto_approve_onshape = None
        self._upgradable = None
        self._user_based = None
        self._self_service_disabled = None
        self._user_limit = None
        self._welcome_html = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if id is not None:
            self.id = id
        if description is not None:
            self.description = description
        if capability is not None:
            self.capability = capability
        if eula is not None:
            self.eula = eula
        if approvals_per_hour is not None:
            self.approvals_per_hour = approvals_per_hour
        if auto_approve is not None:
            self.auto_approve = auto_approve
        if auto_approve_paid is not None:
            self.auto_approve_paid = auto_approve_paid
        if auto_approve_onshape is not None:
            self.auto_approve_onshape = auto_approve_onshape
        if upgradable is not None:
            self.upgradable = upgradable
        if user_based is not None:
            self.user_based = user_based
        if self_service_disabled is not None:
            self.self_service_disabled = self_service_disabled
        if user_limit is not None:
            self.user_limit = user_limit
        if welcome_html is not None:
            self.welcome_html = welcome_html

    @property
    def name(self):
        """Gets the name of this BTBetaCapabilityParams.  # noqa: E501


        :return: The name of this BTBetaCapabilityParams.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTBetaCapabilityParams.


        :param name: The name of this BTBetaCapabilityParams.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this BTBetaCapabilityParams.  # noqa: E501


        :return: The id of this BTBetaCapabilityParams.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BTBetaCapabilityParams.


        :param id: The id of this BTBetaCapabilityParams.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def description(self):
        """Gets the description of this BTBetaCapabilityParams.  # noqa: E501


        :return: The description of this BTBetaCapabilityParams.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BTBetaCapabilityParams.


        :param description: The description of this BTBetaCapabilityParams.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def capability(self):
        """Gets the capability of this BTBetaCapabilityParams.  # noqa: E501


        :return: The capability of this BTBetaCapabilityParams.  # noqa: E501
        :rtype: str
        """
        return self._capability

    @capability.setter
    def capability(self, capability):
        """Sets the capability of this BTBetaCapabilityParams.


        :param capability: The capability of this BTBetaCapabilityParams.  # noqa: E501
        :type: str
        """

        self._capability = capability

    @property
    def eula(self):
        """Gets the eula of this BTBetaCapabilityParams.  # noqa: E501


        :return: The eula of this BTBetaCapabilityParams.  # noqa: E501
        :rtype: str
        """
        return self._eula

    @eula.setter
    def eula(self, eula):
        """Sets the eula of this BTBetaCapabilityParams.


        :param eula: The eula of this BTBetaCapabilityParams.  # noqa: E501
        :type: str
        """

        self._eula = eula

    @property
    def approvals_per_hour(self):
        """Gets the approvals_per_hour of this BTBetaCapabilityParams.  # noqa: E501


        :return: The approvals_per_hour of this BTBetaCapabilityParams.  # noqa: E501
        :rtype: float
        """
        return self._approvals_per_hour

    @approvals_per_hour.setter
    def approvals_per_hour(self, approvals_per_hour):
        """Sets the approvals_per_hour of this BTBetaCapabilityParams.


        :param approvals_per_hour: The approvals_per_hour of this BTBetaCapabilityParams.  # noqa: E501
        :type: float
        """

        self._approvals_per_hour = approvals_per_hour

    @property
    def auto_approve(self):
        """Gets the auto_approve of this BTBetaCapabilityParams.  # noqa: E501


        :return: The auto_approve of this BTBetaCapabilityParams.  # noqa: E501
        :rtype: bool
        """
        return self._auto_approve

    @auto_approve.setter
    def auto_approve(self, auto_approve):
        """Sets the auto_approve of this BTBetaCapabilityParams.


        :param auto_approve: The auto_approve of this BTBetaCapabilityParams.  # noqa: E501
        :type: bool
        """

        self._auto_approve = auto_approve

    @property
    def auto_approve_paid(self):
        """Gets the auto_approve_paid of this BTBetaCapabilityParams.  # noqa: E501


        :return: The auto_approve_paid of this BTBetaCapabilityParams.  # noqa: E501
        :rtype: bool
        """
        return self._auto_approve_paid

    @auto_approve_paid.setter
    def auto_approve_paid(self, auto_approve_paid):
        """Sets the auto_approve_paid of this BTBetaCapabilityParams.


        :param auto_approve_paid: The auto_approve_paid of this BTBetaCapabilityParams.  # noqa: E501
        :type: bool
        """

        self._auto_approve_paid = auto_approve_paid

    @property
    def auto_approve_onshape(self):
        """Gets the auto_approve_onshape of this BTBetaCapabilityParams.  # noqa: E501


        :return: The auto_approve_onshape of this BTBetaCapabilityParams.  # noqa: E501
        :rtype: bool
        """
        return self._auto_approve_onshape

    @auto_approve_onshape.setter
    def auto_approve_onshape(self, auto_approve_onshape):
        """Sets the auto_approve_onshape of this BTBetaCapabilityParams.


        :param auto_approve_onshape: The auto_approve_onshape of this BTBetaCapabilityParams.  # noqa: E501
        :type: bool
        """

        self._auto_approve_onshape = auto_approve_onshape

    @property
    def upgradable(self):
        """Gets the upgradable of this BTBetaCapabilityParams.  # noqa: E501


        :return: The upgradable of this BTBetaCapabilityParams.  # noqa: E501
        :rtype: bool
        """
        return self._upgradable

    @upgradable.setter
    def upgradable(self, upgradable):
        """Sets the upgradable of this BTBetaCapabilityParams.


        :param upgradable: The upgradable of this BTBetaCapabilityParams.  # noqa: E501
        :type: bool
        """

        self._upgradable = upgradable

    @property
    def user_based(self):
        """Gets the user_based of this BTBetaCapabilityParams.  # noqa: E501


        :return: The user_based of this BTBetaCapabilityParams.  # noqa: E501
        :rtype: bool
        """
        return self._user_based

    @user_based.setter
    def user_based(self, user_based):
        """Sets the user_based of this BTBetaCapabilityParams.


        :param user_based: The user_based of this BTBetaCapabilityParams.  # noqa: E501
        :type: bool
        """

        self._user_based = user_based

    @property
    def self_service_disabled(self):
        """Gets the self_service_disabled of this BTBetaCapabilityParams.  # noqa: E501


        :return: The self_service_disabled of this BTBetaCapabilityParams.  # noqa: E501
        :rtype: bool
        """
        return self._self_service_disabled

    @self_service_disabled.setter
    def self_service_disabled(self, self_service_disabled):
        """Sets the self_service_disabled of this BTBetaCapabilityParams.


        :param self_service_disabled: The self_service_disabled of this BTBetaCapabilityParams.  # noqa: E501
        :type: bool
        """

        self._self_service_disabled = self_service_disabled

    @property
    def user_limit(self):
        """Gets the user_limit of this BTBetaCapabilityParams.  # noqa: E501


        :return: The user_limit of this BTBetaCapabilityParams.  # noqa: E501
        :rtype: int
        """
        return self._user_limit

    @user_limit.setter
    def user_limit(self, user_limit):
        """Sets the user_limit of this BTBetaCapabilityParams.


        :param user_limit: The user_limit of this BTBetaCapabilityParams.  # noqa: E501
        :type: int
        """

        self._user_limit = user_limit

    @property
    def welcome_html(self):
        """Gets the welcome_html of this BTBetaCapabilityParams.  # noqa: E501


        :return: The welcome_html of this BTBetaCapabilityParams.  # noqa: E501
        :rtype: str
        """
        return self._welcome_html

    @welcome_html.setter
    def welcome_html(self, welcome_html):
        """Sets the welcome_html of this BTBetaCapabilityParams.


        :param welcome_html: The welcome_html of this BTBetaCapabilityParams.  # noqa: E501
        :type: str
        """

        self._welcome_html = welcome_html

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTBetaCapabilityParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTStandardContentParameterDefinition(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'default_value': 'str',
        'display_name': 'str',
        'is_driving_configuration': 'bool',
        'parameter_id': 'str',
        'visible': 'bool',
        'is_custom_parameter': 'bool'
    }

    attribute_map = {
        'default_value': 'defaultValue',
        'display_name': 'displayName',
        'is_driving_configuration': 'isDrivingConfiguration',
        'parameter_id': 'parameterId',
        'visible': 'visible',
        'is_custom_parameter': 'isCustomParameter'
    }

    def __init__(self, default_value=None, display_name=None, is_driving_configuration=None, parameter_id=None, visible=None, is_custom_parameter=None):  # noqa: E501
        """BTStandardContentParameterDefinition - a model defined in OpenAPI"""  # noqa: E501

        self._default_value = None
        self._display_name = None
        self._is_driving_configuration = None
        self._parameter_id = None
        self._visible = None
        self._is_custom_parameter = None
        self.discriminator = None

        if default_value is not None:
            self.default_value = default_value
        if display_name is not None:
            self.display_name = display_name
        if is_driving_configuration is not None:
            self.is_driving_configuration = is_driving_configuration
        if parameter_id is not None:
            self.parameter_id = parameter_id
        if visible is not None:
            self.visible = visible
        if is_custom_parameter is not None:
            self.is_custom_parameter = is_custom_parameter

    @property
    def default_value(self):
        """Gets the default_value of this BTStandardContentParameterDefinition.  # noqa: E501


        :return: The default_value of this BTStandardContentParameterDefinition.  # noqa: E501
        :rtype: str
        """
        return self._default_value

    @default_value.setter
    def default_value(self, default_value):
        """Sets the default_value of this BTStandardContentParameterDefinition.


        :param default_value: The default_value of this BTStandardContentParameterDefinition.  # noqa: E501
        :type: str
        """

        self._default_value = default_value

    @property
    def display_name(self):
        """Gets the display_name of this BTStandardContentParameterDefinition.  # noqa: E501


        :return: The display_name of this BTStandardContentParameterDefinition.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this BTStandardContentParameterDefinition.


        :param display_name: The display_name of this BTStandardContentParameterDefinition.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def is_driving_configuration(self):
        """Gets the is_driving_configuration of this BTStandardContentParameterDefinition.  # noqa: E501


        :return: The is_driving_configuration of this BTStandardContentParameterDefinition.  # noqa: E501
        :rtype: bool
        """
        return self._is_driving_configuration

    @is_driving_configuration.setter
    def is_driving_configuration(self, is_driving_configuration):
        """Sets the is_driving_configuration of this BTStandardContentParameterDefinition.


        :param is_driving_configuration: The is_driving_configuration of this BTStandardContentParameterDefinition.  # noqa: E501
        :type: bool
        """

        self._is_driving_configuration = is_driving_configuration

    @property
    def parameter_id(self):
        """Gets the parameter_id of this BTStandardContentParameterDefinition.  # noqa: E501


        :return: The parameter_id of this BTStandardContentParameterDefinition.  # noqa: E501
        :rtype: str
        """
        return self._parameter_id

    @parameter_id.setter
    def parameter_id(self, parameter_id):
        """Sets the parameter_id of this BTStandardContentParameterDefinition.


        :param parameter_id: The parameter_id of this BTStandardContentParameterDefinition.  # noqa: E501
        :type: str
        """

        self._parameter_id = parameter_id

    @property
    def visible(self):
        """Gets the visible of this BTStandardContentParameterDefinition.  # noqa: E501


        :return: The visible of this BTStandardContentParameterDefinition.  # noqa: E501
        :rtype: bool
        """
        return self._visible

    @visible.setter
    def visible(self, visible):
        """Sets the visible of this BTStandardContentParameterDefinition.


        :param visible: The visible of this BTStandardContentParameterDefinition.  # noqa: E501
        :type: bool
        """

        self._visible = visible

    @property
    def is_custom_parameter(self):
        """Gets the is_custom_parameter of this BTStandardContentParameterDefinition.  # noqa: E501


        :return: The is_custom_parameter of this BTStandardContentParameterDefinition.  # noqa: E501
        :rtype: bool
        """
        return self._is_custom_parameter

    @is_custom_parameter.setter
    def is_custom_parameter(self, is_custom_parameter):
        """Sets the is_custom_parameter of this BTStandardContentParameterDefinition.


        :param is_custom_parameter: The is_custom_parameter of this BTStandardContentParameterDefinition.  # noqa: E501
        :type: bool
        """

        self._is_custom_parameter = is_custom_parameter

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTStandardContentParameterDefinition):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTBulkDocumentUpdateParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'document_ids': 'str',
        'update_property': 'str',
        'skip_upgrade_version': 'int',
        'skip_upgrade': 'bool',
        'upgrade_mode': 'str',
        'upgrade_version': 'int'
    }

    attribute_map = {
        'document_ids': 'documentIds',
        'update_property': 'updateProperty',
        'skip_upgrade_version': 'skipUpgradeVersion',
        'skip_upgrade': 'skipUpgrade',
        'upgrade_mode': 'upgradeMode',
        'upgrade_version': 'upgradeVersion'
    }

    def __init__(self, document_ids=None, update_property=None, skip_upgrade_version=None, skip_upgrade=None, upgrade_mode=None, upgrade_version=None):  # noqa: E501
        """BTBulkDocumentUpdateParams - a model defined in OpenAPI"""  # noqa: E501

        self._document_ids = None
        self._update_property = None
        self._skip_upgrade_version = None
        self._skip_upgrade = None
        self._upgrade_mode = None
        self._upgrade_version = None
        self.discriminator = None

        if document_ids is not None:
            self.document_ids = document_ids
        if update_property is not None:
            self.update_property = update_property
        if skip_upgrade_version is not None:
            self.skip_upgrade_version = skip_upgrade_version
        if skip_upgrade is not None:
            self.skip_upgrade = skip_upgrade
        if upgrade_mode is not None:
            self.upgrade_mode = upgrade_mode
        if upgrade_version is not None:
            self.upgrade_version = upgrade_version

    @property
    def document_ids(self):
        """Gets the document_ids of this BTBulkDocumentUpdateParams.  # noqa: E501


        :return: The document_ids of this BTBulkDocumentUpdateParams.  # noqa: E501
        :rtype: str
        """
        return self._document_ids

    @document_ids.setter
    def document_ids(self, document_ids):
        """Sets the document_ids of this BTBulkDocumentUpdateParams.


        :param document_ids: The document_ids of this BTBulkDocumentUpdateParams.  # noqa: E501
        :type: str
        """

        self._document_ids = document_ids

    @property
    def update_property(self):
        """Gets the update_property of this BTBulkDocumentUpdateParams.  # noqa: E501


        :return: The update_property of this BTBulkDocumentUpdateParams.  # noqa: E501
        :rtype: str
        """
        return self._update_property

    @update_property.setter
    def update_property(self, update_property):
        """Sets the update_property of this BTBulkDocumentUpdateParams.


        :param update_property: The update_property of this BTBulkDocumentUpdateParams.  # noqa: E501
        :type: str
        """

        self._update_property = update_property

    @property
    def skip_upgrade_version(self):
        """Gets the skip_upgrade_version of this BTBulkDocumentUpdateParams.  # noqa: E501


        :return: The skip_upgrade_version of this BTBulkDocumentUpdateParams.  # noqa: E501
        :rtype: int
        """
        return self._skip_upgrade_version

    @skip_upgrade_version.setter
    def skip_upgrade_version(self, skip_upgrade_version):
        """Sets the skip_upgrade_version of this BTBulkDocumentUpdateParams.


        :param skip_upgrade_version: The skip_upgrade_version of this BTBulkDocumentUpdateParams.  # noqa: E501
        :type: int
        """

        self._skip_upgrade_version = skip_upgrade_version

    @property
    def skip_upgrade(self):
        """Gets the skip_upgrade of this BTBulkDocumentUpdateParams.  # noqa: E501


        :return: The skip_upgrade of this BTBulkDocumentUpdateParams.  # noqa: E501
        :rtype: bool
        """
        return self._skip_upgrade

    @skip_upgrade.setter
    def skip_upgrade(self, skip_upgrade):
        """Sets the skip_upgrade of this BTBulkDocumentUpdateParams.


        :param skip_upgrade: The skip_upgrade of this BTBulkDocumentUpdateParams.  # noqa: E501
        :type: bool
        """

        self._skip_upgrade = skip_upgrade

    @property
    def upgrade_mode(self):
        """Gets the upgrade_mode of this BTBulkDocumentUpdateParams.  # noqa: E501


        :return: The upgrade_mode of this BTBulkDocumentUpdateParams.  # noqa: E501
        :rtype: str
        """
        return self._upgrade_mode

    @upgrade_mode.setter
    def upgrade_mode(self, upgrade_mode):
        """Sets the upgrade_mode of this BTBulkDocumentUpdateParams.


        :param upgrade_mode: The upgrade_mode of this BTBulkDocumentUpdateParams.  # noqa: E501
        :type: str
        """

        self._upgrade_mode = upgrade_mode

    @property
    def upgrade_version(self):
        """Gets the upgrade_version of this BTBulkDocumentUpdateParams.  # noqa: E501


        :return: The upgrade_version of this BTBulkDocumentUpdateParams.  # noqa: E501
        :rtype: int
        """
        return self._upgrade_version

    @upgrade_version.setter
    def upgrade_version(self, upgrade_version):
        """Sets the upgrade_version of this BTBulkDocumentUpdateParams.


        :param upgrade_version: The upgrade_version of this BTBulkDocumentUpdateParams.  # noqa: E501
        :type: int
        """

        self._upgrade_version = upgrade_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTBulkDocumentUpdateParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class Plan(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'object': 'str',
        'amount': 'int',
        'created': 'int',
        'currency': 'str',
        'interval': 'str',
        'interval_count': 'int',
        'livemode': 'bool',
        'metadata': 'dict(str, str)',
        'name': 'str',
        'statement_descriptor': 'str',
        'trial_period_days': 'int',
        'statement_description': 'str'
    }

    attribute_map = {
        'id': 'id',
        'object': 'object',
        'amount': 'amount',
        'created': 'created',
        'currency': 'currency',
        'interval': 'interval',
        'interval_count': 'intervalCount',
        'livemode': 'livemode',
        'metadata': 'metadata',
        'name': 'name',
        'statement_descriptor': 'statementDescriptor',
        'trial_period_days': 'trialPeriodDays',
        'statement_description': 'statementDescription'
    }

    def __init__(self, id=None, object=None, amount=None, created=None, currency=None, interval=None, interval_count=None, livemode=None, metadata=None, name=None, statement_descriptor=None, trial_period_days=None, statement_description=None):  # noqa: E501
        """Plan - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._object = None
        self._amount = None
        self._created = None
        self._currency = None
        self._interval = None
        self._interval_count = None
        self._livemode = None
        self._metadata = None
        self._name = None
        self._statement_descriptor = None
        self._trial_period_days = None
        self._statement_description = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if object is not None:
            self.object = object
        if amount is not None:
            self.amount = amount
        if created is not None:
            self.created = created
        if currency is not None:
            self.currency = currency
        if interval is not None:
            self.interval = interval
        if interval_count is not None:
            self.interval_count = interval_count
        if livemode is not None:
            self.livemode = livemode
        if metadata is not None:
            self.metadata = metadata
        if name is not None:
            self.name = name
        if statement_descriptor is not None:
            self.statement_descriptor = statement_descriptor
        if trial_period_days is not None:
            self.trial_period_days = trial_period_days
        if statement_description is not None:
            self.statement_description = statement_description

    @property
    def id(self):
        """Gets the id of this Plan.  # noqa: E501


        :return: The id of this Plan.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Plan.


        :param id: The id of this Plan.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def object(self):
        """Gets the object of this Plan.  # noqa: E501


        :return: The object of this Plan.  # noqa: E501
        :rtype: str
        """
        return self._object

    @object.setter
    def object(self, object):
        """Sets the object of this Plan.


        :param object: The object of this Plan.  # noqa: E501
        :type: str
        """

        self._object = object

    @property
    def amount(self):
        """Gets the amount of this Plan.  # noqa: E501


        :return: The amount of this Plan.  # noqa: E501
        :rtype: int
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this Plan.


        :param amount: The amount of this Plan.  # noqa: E501
        :type: int
        """

        self._amount = amount

    @property
    def created(self):
        """Gets the created of this Plan.  # noqa: E501


        :return: The created of this Plan.  # noqa: E501
        :rtype: int
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this Plan.


        :param created: The created of this Plan.  # noqa: E501
        :type: int
        """

        self._created = created

    @property
    def currency(self):
        """Gets the currency of this Plan.  # noqa: E501


        :return: The currency of this Plan.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this Plan.


        :param currency: The currency of this Plan.  # noqa: E501
        :type: str
        """

        self._currency = currency

    @property
    def interval(self):
        """Gets the interval of this Plan.  # noqa: E501


        :return: The interval of this Plan.  # noqa: E501
        :rtype: str
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        """Sets the interval of this Plan.


        :param interval: The interval of this Plan.  # noqa: E501
        :type: str
        """

        self._interval = interval

    @property
    def interval_count(self):
        """Gets the interval_count of this Plan.  # noqa: E501


        :return: The interval_count of this Plan.  # noqa: E501
        :rtype: int
        """
        return self._interval_count

    @interval_count.setter
    def interval_count(self, interval_count):
        """Sets the interval_count of this Plan.


        :param interval_count: The interval_count of this Plan.  # noqa: E501
        :type: int
        """

        self._interval_count = interval_count

    @property
    def livemode(self):
        """Gets the livemode of this Plan.  # noqa: E501


        :return: The livemode of this Plan.  # noqa: E501
        :rtype: bool
        """
        return self._livemode

    @livemode.setter
    def livemode(self, livemode):
        """Sets the livemode of this Plan.


        :param livemode: The livemode of this Plan.  # noqa: E501
        :type: bool
        """

        self._livemode = livemode

    @property
    def metadata(self):
        """Gets the metadata of this Plan.  # noqa: E501


        :return: The metadata of this Plan.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this Plan.


        :param metadata: The metadata of this Plan.  # noqa: E501
        :type: dict(str, str)
        """

        self._metadata = metadata

    @property
    def name(self):
        """Gets the name of this Plan.  # noqa: E501


        :return: The name of this Plan.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Plan.


        :param name: The name of this Plan.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def statement_descriptor(self):
        """Gets the statement_descriptor of this Plan.  # noqa: E501


        :return: The statement_descriptor of this Plan.  # noqa: E501
        :rtype: str
        """
        return self._statement_descriptor

    @statement_descriptor.setter
    def statement_descriptor(self, statement_descriptor):
        """Sets the statement_descriptor of this Plan.


        :param statement_descriptor: The statement_descriptor of this Plan.  # noqa: E501
        :type: str
        """

        self._statement_descriptor = statement_descriptor

    @property
    def trial_period_days(self):
        """Gets the trial_period_days of this Plan.  # noqa: E501


        :return: The trial_period_days of this Plan.  # noqa: E501
        :rtype: int
        """
        return self._trial_period_days

    @trial_period_days.setter
    def trial_period_days(self, trial_period_days):
        """Sets the trial_period_days of this Plan.


        :param trial_period_days: The trial_period_days of this Plan.  # noqa: E501
        :type: int
        """

        self._trial_period_days = trial_period_days

    @property
    def statement_description(self):
        """Gets the statement_description of this Plan.  # noqa: E501


        :return: The statement_description of this Plan.  # noqa: E501
        :rtype: str
        """
        return self._statement_description

    @statement_description.setter
    def statement_description(self, statement_description):
        """Sets the statement_description of this Plan.


        :param statement_description: The statement_description of this Plan.  # noqa: E501
        :type: str
        """

        self._statement_description = statement_description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Plan):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class Components(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'schemas': 'dict(str, Schema)',
        'responses': 'dict(str, ApiResponse)',
        'parameters': 'dict(str, Parameter)',
        'examples': 'dict(str, Example)',
        'request_bodies': 'dict(str, RequestBody)',
        'headers': 'dict(str, Header)',
        'security_schemes': 'dict(str, SecurityScheme)',
        'links': 'dict(str, Link)',
        'callbacks': 'dict(str, Callback)',
        'extensions': 'dict(str, object)'
    }

    attribute_map = {
        'schemas': 'schemas',
        'responses': 'responses',
        'parameters': 'parameters',
        'examples': 'examples',
        'request_bodies': 'requestBodies',
        'headers': 'headers',
        'security_schemes': 'securitySchemes',
        'links': 'links',
        'callbacks': 'callbacks',
        'extensions': 'extensions'
    }

    def __init__(self, schemas=None, responses=None, parameters=None, examples=None, request_bodies=None, headers=None, security_schemes=None, links=None, callbacks=None, extensions=None):  # noqa: E501
        """Components - a model defined in OpenAPI"""  # noqa: E501

        self._schemas = None
        self._responses = None
        self._parameters = None
        self._examples = None
        self._request_bodies = None
        self._headers = None
        self._security_schemes = None
        self._links = None
        self._callbacks = None
        self._extensions = None
        self.discriminator = None

        if schemas is not None:
            self.schemas = schemas
        if responses is not None:
            self.responses = responses
        if parameters is not None:
            self.parameters = parameters
        if examples is not None:
            self.examples = examples
        if request_bodies is not None:
            self.request_bodies = request_bodies
        if headers is not None:
            self.headers = headers
        if security_schemes is not None:
            self.security_schemes = security_schemes
        if links is not None:
            self.links = links
        if callbacks is not None:
            self.callbacks = callbacks
        if extensions is not None:
            self.extensions = extensions

    @property
    def schemas(self):
        """Gets the schemas of this Components.  # noqa: E501


        :return: The schemas of this Components.  # noqa: E501
        :rtype: dict(str, Schema)
        """
        return self._schemas

    @schemas.setter
    def schemas(self, schemas):
        """Sets the schemas of this Components.


        :param schemas: The schemas of this Components.  # noqa: E501
        :type: dict(str, Schema)
        """

        self._schemas = schemas

    @property
    def responses(self):
        """Gets the responses of this Components.  # noqa: E501


        :return: The responses of this Components.  # noqa: E501
        :rtype: dict(str, ApiResponse)
        """
        return self._responses

    @responses.setter
    def responses(self, responses):
        """Sets the responses of this Components.


        :param responses: The responses of this Components.  # noqa: E501
        :type: dict(str, ApiResponse)
        """

        self._responses = responses

    @property
    def parameters(self):
        """Gets the parameters of this Components.  # noqa: E501


        :return: The parameters of this Components.  # noqa: E501
        :rtype: dict(str, Parameter)
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this Components.


        :param parameters: The parameters of this Components.  # noqa: E501
        :type: dict(str, Parameter)
        """

        self._parameters = parameters

    @property
    def examples(self):
        """Gets the examples of this Components.  # noqa: E501


        :return: The examples of this Components.  # noqa: E501
        :rtype: dict(str, Example)
        """
        return self._examples

    @examples.setter
    def examples(self, examples):
        """Sets the examples of this Components.


        :param examples: The examples of this Components.  # noqa: E501
        :type: dict(str, Example)
        """

        self._examples = examples

    @property
    def request_bodies(self):
        """Gets the request_bodies of this Components.  # noqa: E501


        :return: The request_bodies of this Components.  # noqa: E501
        :rtype: dict(str, RequestBody)
        """
        return self._request_bodies

    @request_bodies.setter
    def request_bodies(self, request_bodies):
        """Sets the request_bodies of this Components.


        :param request_bodies: The request_bodies of this Components.  # noqa: E501
        :type: dict(str, RequestBody)
        """

        self._request_bodies = request_bodies

    @property
    def headers(self):
        """Gets the headers of this Components.  # noqa: E501


        :return: The headers of this Components.  # noqa: E501
        :rtype: dict(str, Header)
        """
        return self._headers

    @headers.setter
    def headers(self, headers):
        """Sets the headers of this Components.


        :param headers: The headers of this Components.  # noqa: E501
        :type: dict(str, Header)
        """

        self._headers = headers

    @property
    def security_schemes(self):
        """Gets the security_schemes of this Components.  # noqa: E501


        :return: The security_schemes of this Components.  # noqa: E501
        :rtype: dict(str, SecurityScheme)
        """
        return self._security_schemes

    @security_schemes.setter
    def security_schemes(self, security_schemes):
        """Sets the security_schemes of this Components.


        :param security_schemes: The security_schemes of this Components.  # noqa: E501
        :type: dict(str, SecurityScheme)
        """

        self._security_schemes = security_schemes

    @property
    def links(self):
        """Gets the links of this Components.  # noqa: E501


        :return: The links of this Components.  # noqa: E501
        :rtype: dict(str, Link)
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this Components.


        :param links: The links of this Components.  # noqa: E501
        :type: dict(str, Link)
        """

        self._links = links

    @property
    def callbacks(self):
        """Gets the callbacks of this Components.  # noqa: E501


        :return: The callbacks of this Components.  # noqa: E501
        :rtype: dict(str, Callback)
        """
        return self._callbacks

    @callbacks.setter
    def callbacks(self, callbacks):
        """Sets the callbacks of this Components.


        :param callbacks: The callbacks of this Components.  # noqa: E501
        :type: dict(str, Callback)
        """

        self._callbacks = callbacks

    @property
    def extensions(self):
        """Gets the extensions of this Components.  # noqa: E501


        :return: The extensions of this Components.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._extensions

    @extensions.setter
    def extensions(self, extensions):
        """Sets the extensions of this Components.


        :param extensions: The extensions of this Components.  # noqa: E501
        :type: dict(str, object)
        """

        self._extensions = extensions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Components):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class ThreeDSecure(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'object': 'str',
        'amount': 'int',
        'authenticated': 'bool',
        'card': 'Card',
        'created': 'int',
        'currency': 'str',
        'livemode': 'bool',
        'redirect_uri': 'str',
        'status': 'str'
    }

    attribute_map = {
        'id': 'id',
        'object': 'object',
        'amount': 'amount',
        'authenticated': 'authenticated',
        'card': 'card',
        'created': 'created',
        'currency': 'currency',
        'livemode': 'livemode',
        'redirect_uri': 'redirectURL',
        'status': 'status'
    }

    def __init__(self, id=None, object=None, amount=None, authenticated=None, card=None, created=None, currency=None, livemode=None, redirect_url=None, status=None):  # noqa: E501
        """ThreeDSecure - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._object = None
        self._amount = None
        self._authenticated = None
        self._card = None
        self._created = None
        self._currency = None
        self._livemode = None
        self._redirect_url = None
        self._status = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if object is not None:
            self.object = object
        if amount is not None:
            self.amount = amount
        if authenticated is not None:
            self.authenticated = authenticated
        if card is not None:
            self.card = card
        if created is not None:
            self.created = created
        if currency is not None:
            self.currency = currency
        if livemode is not None:
            self.livemode = livemode
        if redirect_url is not None:
            self.redirect_url = redirect_url
        if status is not None:
            self.status = status

    @property
    def id(self):
        """Gets the id of this ThreeDSecure.  # noqa: E501


        :return: The id of this ThreeDSecure.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ThreeDSecure.


        :param id: The id of this ThreeDSecure.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def object(self):
        """Gets the object of this ThreeDSecure.  # noqa: E501


        :return: The object of this ThreeDSecure.  # noqa: E501
        :rtype: str
        """
        return self._object

    @object.setter
    def object(self, object):
        """Sets the object of this ThreeDSecure.


        :param object: The object of this ThreeDSecure.  # noqa: E501
        :type: str
        """

        self._object = object

    @property
    def amount(self):
        """Gets the amount of this ThreeDSecure.  # noqa: E501


        :return: The amount of this ThreeDSecure.  # noqa: E501
        :rtype: int
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this ThreeDSecure.


        :param amount: The amount of this ThreeDSecure.  # noqa: E501
        :type: int
        """

        self._amount = amount

    @property
    def authenticated(self):
        """Gets the authenticated of this ThreeDSecure.  # noqa: E501


        :return: The authenticated of this ThreeDSecure.  # noqa: E501
        :rtype: bool
        """
        return self._authenticated

    @authenticated.setter
    def authenticated(self, authenticated):
        """Sets the authenticated of this ThreeDSecure.


        :param authenticated: The authenticated of this ThreeDSecure.  # noqa: E501
        :type: bool
        """

        self._authenticated = authenticated

    @property
    def card(self):
        """Gets the card of this ThreeDSecure.  # noqa: E501


        :return: The card of this ThreeDSecure.  # noqa: E501
        :rtype: Card
        """
        return self._card

    @card.setter
    def card(self, card):
        """Sets the card of this ThreeDSecure.


        :param card: The card of this ThreeDSecure.  # noqa: E501
        :type: Card
        """

        self._card = card

    @property
    def created(self):
        """Gets the created of this ThreeDSecure.  # noqa: E501


        :return: The created of this ThreeDSecure.  # noqa: E501
        :rtype: int
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this ThreeDSecure.


        :param created: The created of this ThreeDSecure.  # noqa: E501
        :type: int
        """

        self._created = created

    @property
    def currency(self):
        """Gets the currency of this ThreeDSecure.  # noqa: E501


        :return: The currency of this ThreeDSecure.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this ThreeDSecure.


        :param currency: The currency of this ThreeDSecure.  # noqa: E501
        :type: str
        """

        self._currency = currency

    @property
    def livemode(self):
        """Gets the livemode of this ThreeDSecure.  # noqa: E501


        :return: The livemode of this ThreeDSecure.  # noqa: E501
        :rtype: bool
        """
        return self._livemode

    @livemode.setter
    def livemode(self, livemode):
        """Sets the livemode of this ThreeDSecure.


        :param livemode: The livemode of this ThreeDSecure.  # noqa: E501
        :type: bool
        """

        self._livemode = livemode

    @property
    def redirect_url(self):
        """Gets the redirect_uri of this ThreeDSecure.  # noqa: E501


        :return: The redirect_uri of this ThreeDSecure.  # noqa: E501
        :rtype: str
        """
        return self._redirect_url

    @redirect_url.setter
    def redirect_url(self, redirect_url):
        """Sets the redirect_uri of this ThreeDSecure.


        :param redirect_url: The redirect_uri of this ThreeDSecure.  # noqa: E501
        :type: str
        """

        self._redirect_url = redirect_url

    @property
    def status(self):
        """Gets the status of this ThreeDSecure.  # noqa: E501


        :return: The status of this ThreeDSecure.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ThreeDSecure.


        :param status: The status of this ThreeDSecure.  # noqa: E501
        :type: str
        """

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ThreeDSecure):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from onshape_client.api_client import ApiClient


class AccountsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def cancel_purchase_new(self, aid, pid, **kwargs):  # noqa: E501
        """Cancel Recurring Subscription  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel_purchase_new(aid, pid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str aid: (required)
        :param str pid: (required)
        :param bool cancel_immediately:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cancel_purchase_new_with_http_info(aid, pid, **kwargs)  # noqa: E501
        else:
            (data) = self.cancel_purchase_new_with_http_info(aid, pid, **kwargs)  # noqa: E501
            return data

    def cancel_purchase_new_with_http_info(self, aid, pid, **kwargs):  # noqa: E501
        """Cancel Recurring Subscription  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel_purchase_new_with_http_info(aid, pid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str aid: (required)
        :param str pid: (required)
        :param bool cancel_immediately:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['aid', 'pid', 'cancel_immediately']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cancel_purchase_new" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'aid' is set
        if ('aid' not in local_var_params or
                local_var_params['aid'] is None):
            raise ValueError("Missing the required parameter `aid` when calling `cancel_purchase_new`")  # noqa: E501
        # verify the required parameter 'pid' is set
        if ('pid' not in local_var_params or
                local_var_params['pid'] is None):
            raise ValueError("Missing the required parameter `pid` when calling `cancel_purchase_new`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'aid' in local_var_params:
            path_params['aid'] = local_var_params['aid']  # noqa: E501
        if 'pid' in local_var_params:
            path_params['pid'] = local_var_params['pid']  # noqa: E501

        query_params = []
        if 'cancel_immediately' in local_var_params:
            query_params.append(('cancelImmediately', local_var_params['cancel_immediately']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/accounts/{aid}/purchases/{pid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def consume_purchase(self, pid, **kwargs):  # noqa: E501
        """Mark Purchase Consumed For User  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.consume_purchase(pid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str pid: (required)
        :param BTPurchaseUserParams bt_purchase_user_params:
        :return: BTPurchaseInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.consume_purchase_with_http_info(pid, **kwargs)  # noqa: E501
        else:
            (data) = self.consume_purchase_with_http_info(pid, **kwargs)  # noqa: E501
            return data

    def consume_purchase_with_http_info(self, pid, **kwargs):  # noqa: E501
        """Mark Purchase Consumed For User  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.consume_purchase_with_http_info(pid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str pid: (required)
        :param BTPurchaseUserParams bt_purchase_user_params:
        :return: BTPurchaseInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['pid', 'bt_purchase_user_params']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method consume_purchase" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'pid' is set
        if ('pid' not in local_var_params or
                local_var_params['pid'] is None):
            raise ValueError("Missing the required parameter `pid` when calling `consume_purchase`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'pid' in local_var_params:
            path_params['pid'] = local_var_params['pid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'bt_purchase_user_params' in local_var_params:
            body_params = local_var_params['bt_purchase_user_params']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/accounts/purchases/{pid}/consume', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BTPurchaseInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_plan_purchases(self, plan_id, **kwargs):  # noqa: E501
        """Get Plan Purchases  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_plan_purchases(plan_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str plan_id: (required)
        :param int offset:
        :param int limit:
        :return: BTListResponseBTPurchaseInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_plan_purchases_with_http_info(plan_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_plan_purchases_with_http_info(plan_id, **kwargs)  # noqa: E501
            return data

    def get_plan_purchases_with_http_info(self, plan_id, **kwargs):  # noqa: E501
        """Get Plan Purchases  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_plan_purchases_with_http_info(plan_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str plan_id: (required)
        :param int offset:
        :param int limit:
        :return: BTListResponseBTPurchaseInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['plan_id', 'offset', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_plan_purchases" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'plan_id' is set
        if ('plan_id' not in local_var_params or
                local_var_params['plan_id'] is None):
            raise ValueError("Missing the required parameter `plan_id` when calling `get_plan_purchases`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'plan_id' in local_var_params:
            path_params['planId'] = local_var_params['plan_id']  # noqa: E501

        query_params = []
        if 'offset' in local_var_params:
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501
        if 'limit' in local_var_params:
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/accounts/plans/{planId}/purchases', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BTListResponseBTPurchaseInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_purchases(self, **kwargs):  # noqa: E501
        """Get User's Appstore Purchases.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_purchases(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param bool all:
        :param bool own_purchase_only:
        :return: list[BTPurchaseInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_purchases_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_purchases_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_purchases_with_http_info(self, **kwargs):  # noqa: E501
        """Get User's Appstore Purchases.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_purchases_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param bool all:
        :param bool own_purchase_only:
        :return: list[BTPurchaseInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['all', 'own_purchase_only']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_purchases" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'all' in local_var_params:
            query_params.append(('all', local_var_params['all']))  # noqa: E501
        if 'own_purchase_only' in local_var_params:
            query_params.append(('ownPurchaseOnly', local_var_params['own_purchase_only']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/accounts/purchases', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[BTPurchaseInfo]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTPurchaseInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'state': 'int',
        'last_modified': 'datetime',
        'group': 'str',
        'duration': 'int',
        'plan_type': 'int',
        'amount_cents': 'int',
        'currency': 'str',
        'account_id': 'str',
        'plan_id': 'str',
        'plan': 'BTBillingPlanInfo',
        'seats': 'int',
        'subscription_begin_at': 'datetime',
        'subscription_end_at': 'datetime',
        'subscription_id': 'str',
        'application': 'BTAPIApplicationSummaryInfo',
        'client_id': 'str',
        'subscribers': 'list[BTPlanSubscriberInfo]',
        'payment_type': 'int',
        'card': 'BTCardInfo',
        'light_seats': 'int',
        'canceled_at': 'datetime',
        'plan_name': 'str',
        'actual_amount_paid_cents': 'int',
        'trial_end': 'datetime',
        'reseller_name': 'str',
        'coupon_percent_off': 'int',
        'subscription_fields': 'Subscription',
        'purchase_date': 'datetime',
        'pending_cancelation': 'bool',
        'next_charge': 'NextCharge',
        'prorated_charges': 'list[ProratedCharges]',
        'prorated_total': 'int',
        'coupon_amount_off': 'int',
        'duration_months': 'int',
        'name': 'str',
        'id': 'str',
        'href': 'str',
        'view_ref': 'str'
    }

    attribute_map = {
        'state': 'state',
        'last_modified': 'lastModified',
        'group': 'group',
        'duration': 'duration',
        'plan_type': 'planType',
        'amount_cents': 'amountCents',
        'currency': 'currency',
        'account_id': 'accountId',
        'plan_id': 'planId',
        'plan': 'plan',
        'seats': 'seats',
        'subscription_begin_at': 'subscriptionBeginAt',
        'subscription_end_at': 'subscriptionEndAt',
        'subscription_id': 'subscriptionId',
        'application': 'application',
        'client_id': 'clientId',
        'subscribers': 'subscribers',
        'payment_type': 'paymentType',
        'card': 'card',
        'light_seats': 'lightSeats',
        'canceled_at': 'canceledAt',
        'plan_name': 'planName',
        'actual_amount_paid_cents': 'actualAmountPaidCents',
        'trial_end': 'trialEnd',
        'reseller_name': 'resellerName',
        'coupon_percent_off': 'couponPercentOff',
        'subscription_fields': 'subscriptionFields',
        'purchase_date': 'purchaseDate',
        'pending_cancelation': 'pendingCancelation',
        'next_charge': 'nextCharge',
        'prorated_charges': 'proratedCharges',
        'prorated_total': 'proratedTotal',
        'coupon_amount_off': 'couponAmountOff',
        'duration_months': 'durationMonths',
        'name': 'name',
        'id': 'id',
        'href': 'href',
        'view_ref': 'viewRef'
    }

    def __init__(self, state=None, last_modified=None, group=None, duration=None, plan_type=None, amount_cents=None, currency=None, account_id=None, plan_id=None, plan=None, seats=None, subscription_begin_at=None, subscription_end_at=None, subscription_id=None, application=None, client_id=None, subscribers=None, payment_type=None, card=None, light_seats=None, canceled_at=None, plan_name=None, actual_amount_paid_cents=None, trial_end=None, reseller_name=None, coupon_percent_off=None, subscription_fields=None, purchase_date=None, pending_cancelation=None, next_charge=None, prorated_charges=None, prorated_total=None, coupon_amount_off=None, duration_months=None, name=None, id=None, href=None, view_ref=None):  # noqa: E501
        """BTPurchaseInfo - a model defined in OpenAPI"""  # noqa: E501

        self._state = None
        self._last_modified = None
        self._group = None
        self._duration = None
        self._plan_type = None
        self._amount_cents = None
        self._currency = None
        self._account_id = None
        self._plan_id = None
        self._plan = None
        self._seats = None
        self._subscription_begin_at = None
        self._subscription_end_at = None
        self._subscription_id = None
        self._application = None
        self._client_id = None
        self._subscribers = None
        self._payment_type = None
        self._card = None
        self._light_seats = None
        self._canceled_at = None
        self._plan_name = None
        self._actual_amount_paid_cents = None
        self._trial_end = None
        self._reseller_name = None
        self._coupon_percent_off = None
        self._subscription_fields = None
        self._purchase_date = None
        self._pending_cancelation = None
        self._next_charge = None
        self._prorated_charges = None
        self._prorated_total = None
        self._coupon_amount_off = None
        self._duration_months = None
        self._name = None
        self._id = None
        self._href = None
        self._view_ref = None
        self.discriminator = None

        if state is not None:
            self.state = state
        if last_modified is not None:
            self.last_modified = last_modified
        if group is not None:
            self.group = group
        if duration is not None:
            self.duration = duration
        if plan_type is not None:
            self.plan_type = plan_type
        if amount_cents is not None:
            self.amount_cents = amount_cents
        if currency is not None:
            self.currency = currency
        if account_id is not None:
            self.account_id = account_id
        if plan_id is not None:
            self.plan_id = plan_id
        if plan is not None:
            self.plan = plan
        if seats is not None:
            self.seats = seats
        if subscription_begin_at is not None:
            self.subscription_begin_at = subscription_begin_at
        if subscription_end_at is not None:
            self.subscription_end_at = subscription_end_at
        if subscription_id is not None:
            self.subscription_id = subscription_id
        if application is not None:
            self.application = application
        if client_id is not None:
            self.client_id = client_id
        if subscribers is not None:
            self.subscribers = subscribers
        if payment_type is not None:
            self.payment_type = payment_type
        if card is not None:
            self.card = card
        if light_seats is not None:
            self.light_seats = light_seats
        if canceled_at is not None:
            self.canceled_at = canceled_at
        if plan_name is not None:
            self.plan_name = plan_name
        if actual_amount_paid_cents is not None:
            self.actual_amount_paid_cents = actual_amount_paid_cents
        if trial_end is not None:
            self.trial_end = trial_end
        if reseller_name is not None:
            self.reseller_name = reseller_name
        if coupon_percent_off is not None:
            self.coupon_percent_off = coupon_percent_off
        if subscription_fields is not None:
            self.subscription_fields = subscription_fields
        if purchase_date is not None:
            self.purchase_date = purchase_date
        if pending_cancelation is not None:
            self.pending_cancelation = pending_cancelation
        if next_charge is not None:
            self.next_charge = next_charge
        if prorated_charges is not None:
            self.prorated_charges = prorated_charges
        if prorated_total is not None:
            self.prorated_total = prorated_total
        if coupon_amount_off is not None:
            self.coupon_amount_off = coupon_amount_off
        if duration_months is not None:
            self.duration_months = duration_months
        if name is not None:
            self.name = name
        if id is not None:
            self.id = id
        if href is not None:
            self.href = href
        if view_ref is not None:
            self.view_ref = view_ref

    @property
    def state(self):
        """Gets the state of this BTPurchaseInfo.  # noqa: E501


        :return: The state of this BTPurchaseInfo.  # noqa: E501
        :rtype: int
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this BTPurchaseInfo.


        :param state: The state of this BTPurchaseInfo.  # noqa: E501
        :type: int
        """

        self._state = state

    @property
    def last_modified(self):
        """Gets the last_modified of this BTPurchaseInfo.  # noqa: E501


        :return: The last_modified of this BTPurchaseInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._last_modified

    @last_modified.setter
    def last_modified(self, last_modified):
        """Sets the last_modified of this BTPurchaseInfo.


        :param last_modified: The last_modified of this BTPurchaseInfo.  # noqa: E501
        :type: datetime
        """

        self._last_modified = last_modified

    @property
    def group(self):
        """Gets the group of this BTPurchaseInfo.  # noqa: E501


        :return: The group of this BTPurchaseInfo.  # noqa: E501
        :rtype: str
        """
        return self._group

    @group.setter
    def group(self, group):
        """Sets the group of this BTPurchaseInfo.


        :param group: The group of this BTPurchaseInfo.  # noqa: E501
        :type: str
        """

        self._group = group

    @property
    def duration(self):
        """Gets the duration of this BTPurchaseInfo.  # noqa: E501


        :return: The duration of this BTPurchaseInfo.  # noqa: E501
        :rtype: int
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """Sets the duration of this BTPurchaseInfo.


        :param duration: The duration of this BTPurchaseInfo.  # noqa: E501
        :type: int
        """

        self._duration = duration

    @property
    def plan_type(self):
        """Gets the plan_type of this BTPurchaseInfo.  # noqa: E501


        :return: The plan_type of this BTPurchaseInfo.  # noqa: E501
        :rtype: int
        """
        return self._plan_type

    @plan_type.setter
    def plan_type(self, plan_type):
        """Sets the plan_type of this BTPurchaseInfo.


        :param plan_type: The plan_type of this BTPurchaseInfo.  # noqa: E501
        :type: int
        """

        self._plan_type = plan_type

    @property
    def amount_cents(self):
        """Gets the amount_cents of this BTPurchaseInfo.  # noqa: E501


        :return: The amount_cents of this BTPurchaseInfo.  # noqa: E501
        :rtype: int
        """
        return self._amount_cents

    @amount_cents.setter
    def amount_cents(self, amount_cents):
        """Sets the amount_cents of this BTPurchaseInfo.


        :param amount_cents: The amount_cents of this BTPurchaseInfo.  # noqa: E501
        :type: int
        """

        self._amount_cents = amount_cents

    @property
    def currency(self):
        """Gets the currency of this BTPurchaseInfo.  # noqa: E501


        :return: The currency of this BTPurchaseInfo.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this BTPurchaseInfo.


        :param currency: The currency of this BTPurchaseInfo.  # noqa: E501
        :type: str
        """

        self._currency = currency

    @property
    def account_id(self):
        """Gets the account_id of this BTPurchaseInfo.  # noqa: E501


        :return: The account_id of this BTPurchaseInfo.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this BTPurchaseInfo.


        :param account_id: The account_id of this BTPurchaseInfo.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def plan_id(self):
        """Gets the plan_id of this BTPurchaseInfo.  # noqa: E501


        :return: The plan_id of this BTPurchaseInfo.  # noqa: E501
        :rtype: str
        """
        return self._plan_id

    @plan_id.setter
    def plan_id(self, plan_id):
        """Sets the plan_id of this BTPurchaseInfo.


        :param plan_id: The plan_id of this BTPurchaseInfo.  # noqa: E501
        :type: str
        """

        self._plan_id = plan_id

    @property
    def plan(self):
        """Gets the plan of this BTPurchaseInfo.  # noqa: E501


        :return: The plan of this BTPurchaseInfo.  # noqa: E501
        :rtype: BTBillingPlanInfo
        """
        return self._plan

    @plan.setter
    def plan(self, plan):
        """Sets the plan of this BTPurchaseInfo.


        :param plan: The plan of this BTPurchaseInfo.  # noqa: E501
        :type: BTBillingPlanInfo
        """

        self._plan = plan

    @property
    def seats(self):
        """Gets the seats of this BTPurchaseInfo.  # noqa: E501


        :return: The seats of this BTPurchaseInfo.  # noqa: E501
        :rtype: int
        """
        return self._seats

    @seats.setter
    def seats(self, seats):
        """Sets the seats of this BTPurchaseInfo.


        :param seats: The seats of this BTPurchaseInfo.  # noqa: E501
        :type: int
        """

        self._seats = seats

    @property
    def subscription_begin_at(self):
        """Gets the subscription_begin_at of this BTPurchaseInfo.  # noqa: E501


        :return: The subscription_begin_at of this BTPurchaseInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._subscription_begin_at

    @subscription_begin_at.setter
    def subscription_begin_at(self, subscription_begin_at):
        """Sets the subscription_begin_at of this BTPurchaseInfo.


        :param subscription_begin_at: The subscription_begin_at of this BTPurchaseInfo.  # noqa: E501
        :type: datetime
        """

        self._subscription_begin_at = subscription_begin_at

    @property
    def subscription_end_at(self):
        """Gets the subscription_end_at of this BTPurchaseInfo.  # noqa: E501


        :return: The subscription_end_at of this BTPurchaseInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._subscription_end_at

    @subscription_end_at.setter
    def subscription_end_at(self, subscription_end_at):
        """Sets the subscription_end_at of this BTPurchaseInfo.


        :param subscription_end_at: The subscription_end_at of this BTPurchaseInfo.  # noqa: E501
        :type: datetime
        """

        self._subscription_end_at = subscription_end_at

    @property
    def subscription_id(self):
        """Gets the subscription_id of this BTPurchaseInfo.  # noqa: E501


        :return: The subscription_id of this BTPurchaseInfo.  # noqa: E501
        :rtype: str
        """
        return self._subscription_id

    @subscription_id.setter
    def subscription_id(self, subscription_id):
        """Sets the subscription_id of this BTPurchaseInfo.


        :param subscription_id: The subscription_id of this BTPurchaseInfo.  # noqa: E501
        :type: str
        """

        self._subscription_id = subscription_id

    @property
    def application(self):
        """Gets the application of this BTPurchaseInfo.  # noqa: E501


        :return: The application of this BTPurchaseInfo.  # noqa: E501
        :rtype: BTAPIApplicationSummaryInfo
        """
        return self._application

    @application.setter
    def application(self, application):
        """Sets the application of this BTPurchaseInfo.


        :param application: The application of this BTPurchaseInfo.  # noqa: E501
        :type: BTAPIApplicationSummaryInfo
        """

        self._application = application

    @property
    def client_id(self):
        """Gets the client_id of this BTPurchaseInfo.  # noqa: E501


        :return: The client_id of this BTPurchaseInfo.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this BTPurchaseInfo.


        :param client_id: The client_id of this BTPurchaseInfo.  # noqa: E501
        :type: str
        """

        self._client_id = client_id

    @property
    def subscribers(self):
        """Gets the subscribers of this BTPurchaseInfo.  # noqa: E501


        :return: The subscribers of this BTPurchaseInfo.  # noqa: E501
        :rtype: list[BTPlanSubscriberInfo]
        """
        return self._subscribers

    @subscribers.setter
    def subscribers(self, subscribers):
        """Sets the subscribers of this BTPurchaseInfo.


        :param subscribers: The subscribers of this BTPurchaseInfo.  # noqa: E501
        :type: list[BTPlanSubscriberInfo]
        """

        self._subscribers = subscribers

    @property
    def payment_type(self):
        """Gets the payment_type of this BTPurchaseInfo.  # noqa: E501


        :return: The payment_type of this BTPurchaseInfo.  # noqa: E501
        :rtype: int
        """
        return self._payment_type

    @payment_type.setter
    def payment_type(self, payment_type):
        """Sets the payment_type of this BTPurchaseInfo.


        :param payment_type: The payment_type of this BTPurchaseInfo.  # noqa: E501
        :type: int
        """

        self._payment_type = payment_type

    @property
    def card(self):
        """Gets the card of this BTPurchaseInfo.  # noqa: E501


        :return: The card of this BTPurchaseInfo.  # noqa: E501
        :rtype: BTCardInfo
        """
        return self._card

    @card.setter
    def card(self, card):
        """Sets the card of this BTPurchaseInfo.


        :param card: The card of this BTPurchaseInfo.  # noqa: E501
        :type: BTCardInfo
        """

        self._card = card

    @property
    def light_seats(self):
        """Gets the light_seats of this BTPurchaseInfo.  # noqa: E501


        :return: The light_seats of this BTPurchaseInfo.  # noqa: E501
        :rtype: int
        """
        return self._light_seats

    @light_seats.setter
    def light_seats(self, light_seats):
        """Sets the light_seats of this BTPurchaseInfo.


        :param light_seats: The light_seats of this BTPurchaseInfo.  # noqa: E501
        :type: int
        """

        self._light_seats = light_seats

    @property
    def canceled_at(self):
        """Gets the canceled_at of this BTPurchaseInfo.  # noqa: E501


        :return: The canceled_at of this BTPurchaseInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._canceled_at

    @canceled_at.setter
    def canceled_at(self, canceled_at):
        """Sets the canceled_at of this BTPurchaseInfo.


        :param canceled_at: The canceled_at of this BTPurchaseInfo.  # noqa: E501
        :type: datetime
        """

        self._canceled_at = canceled_at

    @property
    def plan_name(self):
        """Gets the plan_name of this BTPurchaseInfo.  # noqa: E501


        :return: The plan_name of this BTPurchaseInfo.  # noqa: E501
        :rtype: str
        """
        return self._plan_name

    @plan_name.setter
    def plan_name(self, plan_name):
        """Sets the plan_name of this BTPurchaseInfo.


        :param plan_name: The plan_name of this BTPurchaseInfo.  # noqa: E501
        :type: str
        """

        self._plan_name = plan_name

    @property
    def actual_amount_paid_cents(self):
        """Gets the actual_amount_paid_cents of this BTPurchaseInfo.  # noqa: E501


        :return: The actual_amount_paid_cents of this BTPurchaseInfo.  # noqa: E501
        :rtype: int
        """
        return self._actual_amount_paid_cents

    @actual_amount_paid_cents.setter
    def actual_amount_paid_cents(self, actual_amount_paid_cents):
        """Sets the actual_amount_paid_cents of this BTPurchaseInfo.


        :param actual_amount_paid_cents: The actual_amount_paid_cents of this BTPurchaseInfo.  # noqa: E501
        :type: int
        """

        self._actual_amount_paid_cents = actual_amount_paid_cents

    @property
    def trial_end(self):
        """Gets the trial_end of this BTPurchaseInfo.  # noqa: E501


        :return: The trial_end of this BTPurchaseInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._trial_end

    @trial_end.setter
    def trial_end(self, trial_end):
        """Sets the trial_end of this BTPurchaseInfo.


        :param trial_end: The trial_end of this BTPurchaseInfo.  # noqa: E501
        :type: datetime
        """

        self._trial_end = trial_end

    @property
    def reseller_name(self):
        """Gets the reseller_name of this BTPurchaseInfo.  # noqa: E501


        :return: The reseller_name of this BTPurchaseInfo.  # noqa: E501
        :rtype: str
        """
        return self._reseller_name

    @reseller_name.setter
    def reseller_name(self, reseller_name):
        """Sets the reseller_name of this BTPurchaseInfo.


        :param reseller_name: The reseller_name of this BTPurchaseInfo.  # noqa: E501
        :type: str
        """

        self._reseller_name = reseller_name

    @property
    def coupon_percent_off(self):
        """Gets the coupon_percent_off of this BTPurchaseInfo.  # noqa: E501


        :return: The coupon_percent_off of this BTPurchaseInfo.  # noqa: E501
        :rtype: int
        """
        return self._coupon_percent_off

    @coupon_percent_off.setter
    def coupon_percent_off(self, coupon_percent_off):
        """Sets the coupon_percent_off of this BTPurchaseInfo.


        :param coupon_percent_off: The coupon_percent_off of this BTPurchaseInfo.  # noqa: E501
        :type: int
        """

        self._coupon_percent_off = coupon_percent_off

    @property
    def subscription_fields(self):
        """Gets the subscription_fields of this BTPurchaseInfo.  # noqa: E501


        :return: The subscription_fields of this BTPurchaseInfo.  # noqa: E501
        :rtype: Subscription
        """
        return self._subscription_fields

    @subscription_fields.setter
    def subscription_fields(self, subscription_fields):
        """Sets the subscription_fields of this BTPurchaseInfo.


        :param subscription_fields: The subscription_fields of this BTPurchaseInfo.  # noqa: E501
        :type: Subscription
        """

        self._subscription_fields = subscription_fields

    @property
    def purchase_date(self):
        """Gets the purchase_date of this BTPurchaseInfo.  # noqa: E501


        :return: The purchase_date of this BTPurchaseInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._purchase_date

    @purchase_date.setter
    def purchase_date(self, purchase_date):
        """Sets the purchase_date of this BTPurchaseInfo.


        :param purchase_date: The purchase_date of this BTPurchaseInfo.  # noqa: E501
        :type: datetime
        """

        self._purchase_date = purchase_date

    @property
    def pending_cancelation(self):
        """Gets the pending_cancelation of this BTPurchaseInfo.  # noqa: E501


        :return: The pending_cancelation of this BTPurchaseInfo.  # noqa: E501
        :rtype: bool
        """
        return self._pending_cancelation

    @pending_cancelation.setter
    def pending_cancelation(self, pending_cancelation):
        """Sets the pending_cancelation of this BTPurchaseInfo.


        :param pending_cancelation: The pending_cancelation of this BTPurchaseInfo.  # noqa: E501
        :type: bool
        """

        self._pending_cancelation = pending_cancelation

    @property
    def next_charge(self):
        """Gets the next_charge of this BTPurchaseInfo.  # noqa: E501


        :return: The next_charge of this BTPurchaseInfo.  # noqa: E501
        :rtype: NextCharge
        """
        return self._next_charge

    @next_charge.setter
    def next_charge(self, next_charge):
        """Sets the next_charge of this BTPurchaseInfo.


        :param next_charge: The next_charge of this BTPurchaseInfo.  # noqa: E501
        :type: NextCharge
        """

        self._next_charge = next_charge

    @property
    def prorated_charges(self):
        """Gets the prorated_charges of this BTPurchaseInfo.  # noqa: E501


        :return: The prorated_charges of this BTPurchaseInfo.  # noqa: E501
        :rtype: list[ProratedCharges]
        """
        return self._prorated_charges

    @prorated_charges.setter
    def prorated_charges(self, prorated_charges):
        """Sets the prorated_charges of this BTPurchaseInfo.


        :param prorated_charges: The prorated_charges of this BTPurchaseInfo.  # noqa: E501
        :type: list[ProratedCharges]
        """

        self._prorated_charges = prorated_charges

    @property
    def prorated_total(self):
        """Gets the prorated_total of this BTPurchaseInfo.  # noqa: E501


        :return: The prorated_total of this BTPurchaseInfo.  # noqa: E501
        :rtype: int
        """
        return self._prorated_total

    @prorated_total.setter
    def prorated_total(self, prorated_total):
        """Sets the prorated_total of this BTPurchaseInfo.


        :param prorated_total: The prorated_total of this BTPurchaseInfo.  # noqa: E501
        :type: int
        """

        self._prorated_total = prorated_total

    @property
    def coupon_amount_off(self):
        """Gets the coupon_amount_off of this BTPurchaseInfo.  # noqa: E501


        :return: The coupon_amount_off of this BTPurchaseInfo.  # noqa: E501
        :rtype: int
        """
        return self._coupon_amount_off

    @coupon_amount_off.setter
    def coupon_amount_off(self, coupon_amount_off):
        """Sets the coupon_amount_off of this BTPurchaseInfo.


        :param coupon_amount_off: The coupon_amount_off of this BTPurchaseInfo.  # noqa: E501
        :type: int
        """

        self._coupon_amount_off = coupon_amount_off

    @property
    def duration_months(self):
        """Gets the duration_months of this BTPurchaseInfo.  # noqa: E501


        :return: The duration_months of this BTPurchaseInfo.  # noqa: E501
        :rtype: int
        """
        return self._duration_months

    @duration_months.setter
    def duration_months(self, duration_months):
        """Sets the duration_months of this BTPurchaseInfo.


        :param duration_months: The duration_months of this BTPurchaseInfo.  # noqa: E501
        :type: int
        """

        self._duration_months = duration_months

    @property
    def name(self):
        """Gets the name of this BTPurchaseInfo.  # noqa: E501


        :return: The name of this BTPurchaseInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTPurchaseInfo.


        :param name: The name of this BTPurchaseInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this BTPurchaseInfo.  # noqa: E501


        :return: The id of this BTPurchaseInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BTPurchaseInfo.


        :param id: The id of this BTPurchaseInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def href(self):
        """Gets the href of this BTPurchaseInfo.  # noqa: E501


        :return: The href of this BTPurchaseInfo.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this BTPurchaseInfo.


        :param href: The href of this BTPurchaseInfo.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def view_ref(self):
        """Gets the view_ref of this BTPurchaseInfo.  # noqa: E501


        :return: The view_ref of this BTPurchaseInfo.  # noqa: E501
        :rtype: str
        """
        return self._view_ref

    @view_ref.setter
    def view_ref(self, view_ref):
        """Sets the view_ref of this BTPurchaseInfo.


        :param view_ref: The view_ref of this BTPurchaseInfo.  # noqa: E501
        :type: str
        """

        self._view_ref = view_ref

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTPurchaseInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class OpenAPI(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'openapi': 'str',
        'info': 'Info',
        'external_docs': 'ExternalDocumentation',
        'servers': 'list[Server]',
        'security': 'list[SecurityRequirement]',
        'tags': 'list[Tag]',
        'paths': 'OAuthFlowScopes',
        'components': 'Components',
        'extensions': 'dict(str, object)'
    }

    attribute_map = {
        'openapi': 'openapi',
        'info': 'info',
        'external_docs': 'externalDocs',
        'servers': 'servers',
        'security': 'security',
        'tags': 'tags',
        'paths': 'paths',
        'components': 'components',
        'extensions': 'extensions'
    }

    def __init__(self, openapi=None, info=None, external_docs=None, servers=None, security=None, tags=None, paths=None, components=None, extensions=None):  # noqa: E501
        """OpenAPI - a model defined in OpenAPI"""  # noqa: E501

        self._openapi = None
        self._info = None
        self._external_docs = None
        self._servers = None
        self._security = None
        self._tags = None
        self._paths = None
        self._components = None
        self._extensions = None
        self.discriminator = None

        if openapi is not None:
            self.openapi = openapi
        if info is not None:
            self.info = info
        if external_docs is not None:
            self.external_docs = external_docs
        if servers is not None:
            self.servers = servers
        if security is not None:
            self.security = security
        if tags is not None:
            self.tags = tags
        if paths is not None:
            self.paths = paths
        if components is not None:
            self.components = components
        if extensions is not None:
            self.extensions = extensions

    @property
    def openapi(self):
        """Gets the openapi of this OpenAPI.  # noqa: E501


        :return: The openapi of this OpenAPI.  # noqa: E501
        :rtype: str
        """
        return self._openapi

    @openapi.setter
    def openapi(self, openapi):
        """Sets the openapi of this OpenAPI.


        :param openapi: The openapi of this OpenAPI.  # noqa: E501
        :type: str
        """

        self._openapi = openapi

    @property
    def info(self):
        """Gets the info of this OpenAPI.  # noqa: E501


        :return: The info of this OpenAPI.  # noqa: E501
        :rtype: Info
        """
        return self._info

    @info.setter
    def info(self, info):
        """Sets the info of this OpenAPI.


        :param info: The info of this OpenAPI.  # noqa: E501
        :type: Info
        """

        self._info = info

    @property
    def external_docs(self):
        """Gets the external_docs of this OpenAPI.  # noqa: E501


        :return: The external_docs of this OpenAPI.  # noqa: E501
        :rtype: ExternalDocumentation
        """
        return self._external_docs

    @external_docs.setter
    def external_docs(self, external_docs):
        """Sets the external_docs of this OpenAPI.


        :param external_docs: The external_docs of this OpenAPI.  # noqa: E501
        :type: ExternalDocumentation
        """

        self._external_docs = external_docs

    @property
    def servers(self):
        """Gets the servers of this OpenAPI.  # noqa: E501


        :return: The servers of this OpenAPI.  # noqa: E501
        :rtype: list[Server]
        """
        return self._servers

    @servers.setter
    def servers(self, servers):
        """Sets the servers of this OpenAPI.


        :param servers: The servers of this OpenAPI.  # noqa: E501
        :type: list[Server]
        """

        self._servers = servers

    @property
    def security(self):
        """Gets the security of this OpenAPI.  # noqa: E501


        :return: The security of this OpenAPI.  # noqa: E501
        :rtype: list[SecurityRequirement]
        """
        return self._security

    @security.setter
    def security(self, security):
        """Sets the security of this OpenAPI.


        :param security: The security of this OpenAPI.  # noqa: E501
        :type: list[SecurityRequirement]
        """

        self._security = security

    @property
    def tags(self):
        """Gets the tags of this OpenAPI.  # noqa: E501


        :return: The tags of this OpenAPI.  # noqa: E501
        :rtype: list[Tag]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this OpenAPI.


        :param tags: The tags of this OpenAPI.  # noqa: E501
        :type: list[Tag]
        """

        self._tags = tags

    @property
    def paths(self):
        """Gets the paths of this OpenAPI.  # noqa: E501


        :return: The paths of this OpenAPI.  # noqa: E501
        :rtype: OAuthFlowScopes
        """
        return self._paths

    @paths.setter
    def paths(self, paths):
        """Sets the paths of this OpenAPI.


        :param paths: The paths of this OpenAPI.  # noqa: E501
        :type: OAuthFlowScopes
        """

        self._paths = paths

    @property
    def components(self):
        """Gets the components of this OpenAPI.  # noqa: E501


        :return: The components of this OpenAPI.  # noqa: E501
        :rtype: Components
        """
        return self._components

    @components.setter
    def components(self, components):
        """Sets the components of this OpenAPI.


        :param components: The components of this OpenAPI.  # noqa: E501
        :type: Components
        """

        self._components = components

    @property
    def extensions(self):
        """Gets the extensions of this OpenAPI.  # noqa: E501


        :return: The extensions of this OpenAPI.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._extensions

    @extensions.setter
    def extensions(self, extensions):
        """Sets the extensions of this OpenAPI.


        :param extensions: The extensions of this OpenAPI.  # noqa: E501
        :type: dict(str, object)
        """

        self._extensions = extensions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OpenAPI):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
